IdtMxNDE contains the results of a mixture Normal model maximum likelihood parameter estimation, with the four different possible variance-covariance configurations.
Hmcdt:Indicates whether we consider an homocedastic (TRUE) or a hetereocedasic model (FALSE)
mleNmuE:Matrix with the maximum likelihood mean vectors estimates by group (each row refers to a group)
mleNmuEse:Matrix with the maximum likelihood means' standard errors by group (each row refers to a group)
CovConfCases:List of the considered configurations
grouping:Inherited from class '>IdtMxE. Factor indicating the group to which each observation belongs to
ModelNames:Inherited from class '>IdtE. The model acronym formed by a "N", indicating a Normal model, followed by the configuration (Case 1 through Case 4)
ModelType:Inherited from class '>IdtE. Indicates the model; always set to "Normal" in objects of the IdtMxNDE class
ModelConfig:Inherited from class '>IdtE. Configuration case of the variance-covariance matrix: Case 1 through Case 4
NIVar:SelCrit:Inherited from class '>IdtE. The model selection criterion; currently, AIC and BIC are implemented
logLiks:Inherited from class '>IdtE. The logarithms of the likelihood function for the different cases
AICs:BICs:BestModel:Inherited from class '>IdtE. Indicates the best model according to the chosen selection criterion
SngD:Inherited from class '>IdtE. Boolean flag indicating whether a single or a mixture of distribution were estimated. Always set to FALSE in objects of class '>IdtMxNDE
Ngrps:signature(x = "IdtMxtNDE"): Linear Discriminant Analysis using the estimated model parameters.
signature(x = "IdtMxtNDE"): Quadratic Discriminant Analysis using the estimated model parameters.
Brito, P., Duarte Silva, A. P. (2012), Modelling Interval Data with Normal and Skew-Normal Distributions. Journal of Applied Statistics 39(1), 3--20.
'>IdtE, '>IdtMxE, '>IdtMxNDRE, '>IdtSngNDE, '>IData, MANOVA