IdtMxSNDE contains the results of a mixture model estimation for the Skew-Normal model, with the four different possible variance-covariance configurations.
Hmcdt:Indicates whether we consider an homocedastic location model (TRUE) or a general model (FALSE)
CovConfCases:List of the considered configurations
grouping:Inherited from class '>IdtMxE. Factor indicating the group to which each observation belongs to
ModelNames:Inherited from class '>IdtE. The model acronym, indicating the model type (currently, N for Normal and SN for Skew-Normal), and the configuration (Case 1 through Case 4)
ModelType:Inherited from class '>IdtE. Indicates the model; currently, Gaussian or Skew-Normal distributions are implemented
ModelConfig:Inherited from class '>IdtE. Configuration case of the variance-covariance matrix: Case 1 through Case 4
NIVar:SelCrit:Inherited from class '>IdtE. The model selection criterion; currently, AIC and BIC are implemented
logLiks:Inherited from class '>IdtE. The logarithms of the likelihood function for the different cases
AICs:BICs:BestModel:Inherited from class '>IdtE. Indicates the best model according to the chosen selection criterion
SngD:Inherited from class '>IdtE. Boolean flag indicating whether a single or a mixture of distribution were estimated. Always set to FALSE in objects of class '>IdtMxSNDE
Ngrps:No methods defined with class IdtMxSNDE in the signature.
Azzalini, A. and Dalla Valle, A. (1996), The multivariate skew-normal distribution. Biometrika 83(4), 715--726.
Brito, P., Duarte Silva, A. P. (2012), Modelling Interval Data with Normal and Skew-Normal Distributions. Journal of Applied Statistics 39(1), 3--20.
'>IdtE, '>IdtMxE, '>IdtSngSNDE, MANOVA, '>IData