IdtNDE is a class union used for storing the estimation results of Normal modelizations for Interval Data.
signature(coef = "IdtNDE"): extracts parameter estimates from objects of type IdtNDE
signature(x = "IdtNDE"): extracts standard errors from objects of type IdtNDE
signature(x = "IdtNDE"): extracts an estimate of the variance-covariance matrix of the paramenters estimators for objects of type IdtNDE
Brito, P., Duarte Silva, A. P. (2012), Modelling Interval Data with Normal and Skew-Normal Distributions. Journal of Applied Statistics 39(1), 3--20.
, mle, fasttle, fulltle,
MANOVA, RobMxtDEst, ,