Learn R Programming

MAINT.Data (version 2.8.0)

pcoordplot-methods: Parallel coordinates plot.

Description

Method pcoordplot displays a parallel coordinates plot, representing the results stored in an IdtMclust-method object.

Usage

# S4 method for IdtMclust
pcoordplot(x,title="Parallel Coordinate Plot",
Seq=c("AllMidP_AllLogR","MidPLogR_VarbyVar"), model ="BestModel", 
legendpar=list(), Components = "All", ...)

Arguments

x

An object of type “IdtMclust” representing the the clusterig
results of an Interval-valued data set obtained by the function “IdtMclust”.

title

The title of the plot.

Seq

The ordering of the coordinates in the plot. Available options are:
“AllMidP_AllLogR”: all MidPoints followed all LogRanges, in the same variable order.
“MidPLogR_VarbyVar”: MidPoints followed by LogRanges, variable by variable.

model

A character vector specifying the the model whose solution is to be displayed.

legendpar

A named list with graphical parameters for the plot legend. Currently only the base R ‘cex.main’ and ‘cex.lab’ parameters are implemented.

...

Graphical arguments to be passed to methods

Components

The set of components to be compared

See Also

IdtMclust, Idtmclust, plotInfCrt

Examples

Run this code

if (FALSE) {

# Create an Interval-Data object containing the intervals of loan data
# (from the Kaggle Data Science platform) aggregated by loan purpose

LbyPIdt <- IData(LoansbyPurpose_minmaxDt,
                 VarNames=c("ln-inc","ln-revolbal","open-acc","total-acc")) 


#Fit homoscedastic Gaussian mixtures with up to ten components

mclustres <- Idtmclust(LbyPIdt,G=1:10)
plotInfCrt(mclustres,legpos="bottomright")

#Display the results of the best mixture according to the BIC

pcoordplot(mclustres)
pcoordplot(mclustres,model="HomG6C1")
pcoordplot(mclustres,model="HomG4C1")


}

Run the code above in your browser using DataLab